pytz_deprecation_shim: Shims to make deprecation of pytz easier
===============================================================

Description
-----------

Shims to make deprecation of pytz easier

License
-------

Apache-2.0

Upstream Contact
----------------

https://pypi.org/project/pytz-deprecation-shim/

